class GarbageDataError(Exception):
    """Garbage Data Exception."""

    pass


class ValueTooSmall(Exception):
    """Small Value Exception."""

    pass


class ValueTooBig(Exception):
    """Huge Value Exception."""

    pass


class BackupAlreadyStarted(Exception):
    """Backup Already Started Exception."""

    pass


class DecodeHashError(Exception):
    """Decode Hash Exception."""

    pass
